Web Socket API
==============

Support for client and server web-socket communications.

Client API
----------

.. autofunction:: hgraph.adaptors.tornado.websocket_client_adaptor.websocket_client_adaptor

.. autofunction:: hgraph.adaptors.tornado.websocket_client_adaptor.websocket_client_adaptor_impl


Server API
----------

.. autofunction:: hgraph.adaptors.tornado.websocket_server_adaptor.websocket_server_handler

.. autofunction:: hgraph.adaptors.tornado.websocket_server_adaptor.websocket_server_adaptor_helper

.. autoclass:: hgraph.adaptors.tornado.websocket_server_adaptor.WebSocketConnectRequest

.. autoclass:: hgraph.adaptors.tornado.websocket_server_adaptor.WebSocketServerRequest

.. autoclass:: hgraph.adaptors.tornado.websocket_server_adaptor.WebSocketClientRequest

.. autoclass:: hgraph.adaptors.tornado.websocket_server_adaptor.WebSocketResponse
